==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/Input/wavpack/translations/wavpack_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_BA">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="37"/>
        <source>WavPack Plugin</source>
        <translation>Вавпак прикључак</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="39"/>
        <source>WavPack Files</source>
        <translation>Вавпак фајлови</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="175"/>
        <source>About WavPack Audio Plugin</source>
        <translation>О Вавпак прикључку</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="176"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Кумп Вавпак прикључак</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="177"/>
        <source>WavPack library version:</source>
        <translation>Издање Вавпак библиотеке:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="179"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Ratio</source>
        <translation>Размјера</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="74"/>
        <source>Version</source>
        <translation>Издање</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/Input/wavpack/translations/wavpack_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_BA">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="38"/>
        <source>WavPack Plugin</source>
        <translation>Вавпак прикључак</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="40"/>
        <source>WavPack Files</source>
        <translation>Вавпак фајлови</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="180"/>
        <source>About WavPack Audio Plugin</source>
        <translation>О Вавпак прикључку</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="181"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Кумп Вавпак прикључак</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="182"/>
        <source>WavPack library version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="184"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Ratio</source>
        <translation>Размјера</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Version</source>
        <translation>Издање</translation>
    </message>
</context>
</TS>
